@@ -41,9 +41,9 @@ def unix():
 
 def stopwatch_start():
   global stopwatchStartTime
-  stopwatchStartTime = round(time.time(), 2)
+  stopwatchStartTime = round(time.time())
   return "Started!"
 def stopwatch_stop():
-  stopwatchLength = round(time.time(), 2) - stopwatchStartTime
+  stopwatchLength = round(time.time()) - stopwatchStartTime
   return stopwatchLength
 
